Name:		satyr
Version:	0.31
Release:	%mkrel 2
Summary:	Tools to create anonymous, machine-friendly problem reports
Group:		Development/Tools
License:	GPLv2+
URL:		https://github.com/abrt/satyr
Source0:	https://github.com/abrt/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:	automake
BuildRequires:	doxygen
BuildRequires:	gcc-c++
BuildRequires:	gdb
BuildRequires:	gperf
BuildRequires:	libtool
BuildRequires:	binutils-devel
BuildRequires:	pkgconfig(json-c)
BuildRequires:	pkgconfig(libdw)
BuildRequires:	pkgconfig(libelf)
BuildRequires:	pkgconfig(nettle)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(rpm)
BuildRequires:	python3-sphinx

Requires:	nettle

# ease upgrade (can be removed for mga9)
Obsoletes:	btparser < 0.26-9
Provides:	btparser = %{version}-%{release}

%description
Satyr is a library that can be used to create and process microreports.
Microreports consist of structured data suitable to be analyzed in a fully
automated manner, though they do not necessarily contain sufficient information
to fix the underlying problem. The reports are designed not to contain any
potentially sensitive data to eliminate the need for review before submission.
Included is a tool that can create microreports and perform some basic
operations on them.

%files
%doc README NEWS
%license COPYING
%{_bindir}/satyr
%{_mandir}/man1/%{name}.1*

#--------------------------------------------------------------------

%define major	4
%define libname	%mklibname %{name} %{major}

%package -n %{libname}
Summary:	Tools to create anonymous, machine-friendly problem reports
Group:		System/Libraries

# ease upgrade (can be removed for mga9)
Obsoletes:	%{_lib}btparser2 < 0.26-9
Provides:	%{_lib}btparser2 = %{version}-%{release}

%description -n %{libname}
Satyr is a library that can be used to create and process microreports.
Microreports consist of structured data suitable to be analyzed in a fully
automated manner, though they do not necessarily contain sufficient information
to fix the underlying problem. The reports are designed not to contain any
potentially sensitive data to eliminate the need for review before submission.
Included is a tool that can create microreports and perform some basic
operations on them.

%files -n %libname
%{_libdir}/lib%{name}.so.%{major}{,.*}

#--------------------------------------------------------------------

%define lib_name_devel %mklibname %{name} -d

%package -n %{lib_name_devel}
Summary:	Development libraries for %{name}
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

# ease upgrade (can be removed for mga9)
Obsoletes:	%{_lib}btparser-devel < 0.26-9
Provides:	%{_lib}btparser-devel = %{version}-%{release}

%description -n %{lib_name_devel}
Development libraries and headers for %{name}.

%files -n %{lib_name_devel}
# The complex pattern below (instead of simlpy *) excludes Makefile{.am,.in}:
%doc apidoc/html/*.{html,png,css,js}
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*

#--------------------------------------------------------------------

%package -n python3-%{name}
Summary:	Python 3 bindings for %{name}
Group:		Development/Python
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
Python 3 bindings for %{name}.

%files -n python3-%{name}
%dir %{python3_sitearch}/%{name}
%{python3_sitearch}/%{name}/*

#--------------------------------------------------------------------

%prep
%setup -q

%build
NOCONFIGURE=1 ./autogen.sh
%configure \
        --with-python3 \
        --disable-static \
        --enable-doxygen-docs

%make_build

%install
%make_install

# Remove all libtool archives (*.la) from modules directory.
find %{buildroot} -name "*.la" -delete

%check
%__make check|| {
    # find and print the logs of failed test
    # do not cat tests/testsuite.log because it contains a lot of bloat
    find tests/testsuite.dir -name "testsuite.log" -print -exec cat '{}' \;
    exit 1
}


%changelog
* Mon Nov 30 2020 luigiwalser <luigiwalser> 0.31-2.mga8
+ Revision: 1650736
- rebuild for nettle

* Sat Sep 05 2020 shlomif <shlomif> 0.31-1.mga8
+ Revision: 1622394
- New version 0.31

* Fri Feb 28 2020 daviddavid <daviddavid> 0.30-1.mga8
+ Revision: 1551313
- initial package satyr (a replacement for old btparser)


* Thu Jan 09 2014 Rex Dieter <rdieter@fedoraproject.org> 0.13-3
- track api, abi/soname in %%files, so bumps aren't a surprise

* Tue Jan 07 2014 Martin Milata <mmilata@redhat.com> 0.13-2
- Fix build against elfutils-0.158

* Tue Jan 07 2014 Martin Milata <mmilata@redhat.com> 0.13-1
- New upstream version
  - Kerneloops parser support for ppc64 and s390
  - Kerneloops hashing

* Tue Dec 10 2013 Martin Milata <mmilata@redhat.com> 0.12-1
- New upstream version
  - JVM frames normalization
  - Add C++ symbol demangling
  - Unsigned overflow bugfixes
  - Fix malformed uReports for Java

* Sat Oct 26 2013 Jakub Filak <jfilak@redhat.com> 0.11-1
- New upstream version
  - Make all python objects hashable
  - Improve memory management in rpm module
  - Extend the list of normalized functions
  - Add command for debugging duphashes to satyr utility

* Thu Oct 03 2013 Jakub Filak <jfilak@redhat.com> 0.10-1
- New upstream version
  - Fix a segmentation fault in sr_rpm_package_uniq()
  - Respect kernel flavor when parsing package name
  - Parse backtrace without Thread header
  - Fix koops json output if there are no modules
  - Add support for multiple koops stacks

* Wed Sep 11 2013 Jakub Filak <jfilak@redhat.com> 0.9-1
- New upstream version
  - Enrich koops uReport data with koops text and kernel version.
  - Improve koops modules handling.

* Wed Aug 28 2013 Richard Marko<rmarko@redhat.com> 0.8-1
- New upstream version
  - Added support for json de/serialization of reports and stacktraces.
  - Library version number increased, as the interface changed since the last release

* Mon Aug 26 2013 Martin Milata <mmilata@redhat.com> 0.7-1
- New upstream version
  - Fix couple of crashes (#997076, #994747)

* Mon Jul 29 2013 Martin Milata <mmilata@redhat.com> 0.6-1
- New upstream version
  - Do not export internal function symbols.

* Thu Jul 25 2013 Martin Milata <mmilata@redhat.com> 0.5-2
- Remove libunwind dependency altogether, always use GDB for unwinding.

* Thu Jul 25 2013 Jakub Filak <jfilak@redhat.com> 0.5-1
- Added function that creates core stacktrace from GDB output. Several bugfixes.

* Tue Jul 09 2013 Martin Milata <mmilata@redhat.com> 0.4-2
- Fix failing tests (failure manifests only on s390x)

* Mon Jul 08 2013 Martin Milata <mmilata@redhat.com> 0.4-1
- New upstream version
  - Added features needed by ABRT
  - Support for uReport2
  - Major C and Python API changes
- Patch for python-2.6 compatibility

* Tue Apr 02 2013 Dan Horák <dan[at]danny.cz> 0.3-2
- libunwind exists only on selected arches

* Mon Mar 25 2013 Martin Milata <mmilata@redhat.com> 0.3-1
- New upstream version
  - Bug fixes
  - Build fixes for older systems
- Do not require libunwind on rhel

* Mon Mar 18 2013 Martin Milata <mmilata@redhat.com> 0.2-1
- Documentation and spec cleanup
- Build fixes (build against RPM)

* Mon Aug 30 2010 Karel Klic <kklic@redhat.com> 0.1-1
- Upstream package spec file
